==> ideaIC-172.1909.2-sources.jar: com/intellij/execution/dashboard/tree/RunConfigurationDashboardGroupingRule.java <==
/*
 * Copyright 2000-2017 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.execution.dashboard.tree;

import com.intellij.execution.RunnerAndConfigurationSettings;
import com.intellij.execution.dashboard.DashboardGroup;
import com.intellij.execution.dashboard.DashboardGroupingRule;
import com.intellij.execution.dashboard.DashboardRunConfigurationNode;
import com.intellij.ide.util.treeView.AbstractTreeNode;
import com.intellij.ide.util.treeView.smartTree.ActionPresentation;
import com.intellij.ide.util.treeView.smartTree.ActionPresentationData;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

/**
 * @author konstantin.aleev
 */
public class RunConfigurationDashboardGroupingRule implements DashboardGroupingRule {
  @NotNull
  @Override
  public ActionPresentation getPresentation() {
    return new ActionPresentationData("", "", null);
  }

  @NotNull
  @Override
  public String getName() {
    return "RunConfigurationDashboardGroupingRule";
  }

  @Override
  public int getPriority() {
    return Priorities.BY_RUN_CONFIG;
  }

  @Override
  public boolean isAlwaysEnabled() {
    return true;
  }

  @Override
  public boolean shouldGroupSingleNodes() {
    return false;
  }

  @Nullable
  @Override
  public DashboardGroup getGroup(AbstractTreeNode<?> node) {
    if (node instanceof DashboardRunConfigurationNode) {
      RunnerAndConfigurationSettings configurationSettings = ((DashboardRunConfigurationNode)node).getConfigurationSettings();
      return new DashboardGroupImpl<>(configurationSettings, configurationSettings.getName(), configurationSettings.getConfiguration().getIcon());
    }
    return null;
  }
}

==> ideaIC-173.4301.1-sources.jar: com/intellij/execution/dashboard/tree/RunConfigurationDashboardGroupingRule.java <==
/*
 * Copyright 2000-2017 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.execution.dashboard.tree;

import com.intellij.execution.RunnerAndConfigurationSettings;
import com.intellij.execution.dashboard.RunDashboardGroup;
import com.intellij.execution.dashboard.RunDashboardGroupingRule;
import com.intellij.execution.dashboard.RunDashboardRunConfigurationNode;
import com.intellij.ide.util.treeView.AbstractTreeNode;
import com.intellij.ide.util.treeView.smartTree.ActionPresentation;
import com.intellij.ide.util.treeView.smartTree.ActionPresentationData;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

/**
 * @author konstantin.aleev
 */
public class RunConfigurationDashboardGroupingRule implements RunDashboardGroupingRule {
  @NotNull
  @Override
  public ActionPresentation getPresentation() {
    return new ActionPresentationData("", "", null);
  }

  @NotNull
  @Override
  public String getName() {
    return "RunConfigurationDashboardGroupingRule";
  }

  @Override
  public int getPriority() {
    return Priorities.BY_RUN_CONFIG;
  }

  @Override
  public boolean isAlwaysEnabled() {
    return true;
  }

  @Override
  public boolean shouldGroupSingleNodes() {
    return false;
  }

  @Nullable
  @Override
  public RunDashboardGroup getGroup(AbstractTreeNode<?> node) {
    if (node instanceof RunDashboardRunConfigurationNode) {
      RunnerAndConfigurationSettings configurationSettings = ((RunDashboardRunConfigurationNode)node).getConfigurationSettings();
      return new RunDashboardGroupImpl<>(configurationSettings, configurationSettings.getName(),
                                         configurationSettings.getConfiguration().getIcon());
    }
    return null;
  }
}
